@@ -1,10 +1,10 @@
-/* $Id: VBoxNetAdp-linux.c 126879 2018-11-23 11:17:22Z aleksey $ */
+/* $Id: VBoxNetAdp-linux.c 127855 2019-01-01 01:45:53Z bird $ */
 /** @file
  * VBoxNetAdp - Virtual Network Adapter Driver (Host), Linux Specific Code.
  */
 
 /*
- * Copyright (C) 2009-2017 Oracle Corporation
+ * Copyright (C) 2009-2019 Oracle Corporation
  *
  * This file is part of VirtualBox Open Source Edition (OSE), as
  * available from http://www.virtualbox.org. This file is free software;
@@ -39,7 +39,7 @@
 
 #define LOG_GROUP LOG_GROUP_NET_ADP_DRV
 #include <VBox/log.h>
-#include <VBox/err.h>
+#include <iprt/errcore.h>
 #include <iprt/process.h>
 #include <iprt/initterm.h>
 #include <iprt/mem.h>
