@@ -1,10 +1,10 @@
-/* $Id: alloc-r0drv.h 118810 2017-10-28 13:12:06Z bird $ */
+/* $Id: alloc-r0drv.h 127888 2019-01-01 06:31:29Z bird $ */
 /** @file
  * IPRT - Memory Allocation, Ring-0 Driver.
  */
 
 /*
- * Copyright (C) 2006-2017 Oracle Corporation
+ * Copyright (C) 2006-2019 Oracle Corporation
  *
  * This file is part of VirtualBox Open Source Edition (OSE), as
  * available from http://www.virtualbox.org. This file is free software;
@@ -24,8 +24,11 @@
  * terms and conditions of either the GPL or the CDDL or both.
  */
 
-#ifndef ___r0drv_alloc_r0drv_h
-#define ___r0drv_alloc_r0drv_h
+#ifndef IPRT_INCLUDED_SRC_r0drv_alloc_r0drv_h
+#define IPRT_INCLUDED_SRC_r0drv_alloc_r0drv_h
+#ifndef RT_WITHOUT_PRAGMA_ONCE
+# pragma once
+#endif
 
 #include <iprt/cdefs.h>
 #include <iprt/types.h>
@@ -97,5 +100,5 @@ DECLHIDDEN(int)     rtR0MemAllocEx(size_t cb, uint32_t fFlags, PRTMEMHDR *ppHdr)
 DECLHIDDEN(void)    rtR0MemFree(PRTMEMHDR pHdr);
 
 RT_C_DECLS_END
-#endif
+#endif /* !IPRT_INCLUDED_SRC_r0drv_alloc_r0drv_h */
 
