@@ -1,10 +1,10 @@
-/* $Id: waitqueue-r0drv-linux.h 123434 2018-07-04 16:09:15Z michael $ */
+/* $Id: waitqueue-r0drv-linux.h 127888 2019-01-01 06:31:29Z bird $ */
 /** @file
  * IPRT - Linux Ring-0 Driver Helpers for Abstracting Wait Queues,
  */
 
 /*
- * Copyright (C) 2006-2017 Oracle Corporation
+ * Copyright (C) 2006-2019 Oracle Corporation
  *
  * This file is part of VirtualBox Open Source Edition (OSE), as
  * available from http://www.virtualbox.org. This file is free software;
@@ -24,9 +24,11 @@
  * terms and conditions of either the GPL or the CDDL or both.
  */
 
-
-#ifndef ___r0drv_linux_waitqueue_r0drv_linux_h
-#define ___r0drv_linux_waitqueue_r0drv_linux_h
+#ifndef IPRT_INCLUDED_SRC_r0drv_linux_waitqueue_r0drv_linux_h
+#define IPRT_INCLUDED_SRC_r0drv_linux_waitqueue_r0drv_linux_h
+#ifndef RT_WITHOUT_PRAGMA_ONCE
+# pragma once
+#endif
 
 #include "the-linux-kernel.h"
 
@@ -286,5 +288,5 @@ DECLINLINE(uint32_t) rtR0SemLnxWaitGetResolution(void)
 #endif
 }
 
-#endif
+#endif /* !IPRT_INCLUDED_SRC_r0drv_linux_waitqueue_r0drv_linux_h */
 
